netapp_ontap.resources.nfs_clients_cache API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.nfs_clients_cache`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

This cluster-wide API is used to set the maximum cache idle time (client_retention_interval) for the connected-clients cache. If a client connected to NFS server is idle for longer than than the maximum cache idle time, the entry will be removed. The update_interval value will change when the client_retention_interval is changed. The update interval represents the interval between the cleaning happens. If the value of client_retention_interval is set to 60hrs the connected client entry will stay there for 60 hours and after that it will get removed. If the value of update_interval is 8 hours then the cache will be refreshed once every 8 hours.

## Example

### Retrieves connected-client cache settings information

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NfsClientsCache

    with HostConnection(
        "<cluster-mgmt-ip>", username="admin", password="password", verify=False
    ):
        resource = NfsClientsCache()
        resource.get(return_timeout=15)
        print(resource)

Try it out

    NfsClientsCache({"update_interval": "PT8H", "client_retention_interval": "P7D"})

### Updating connected-client cache settings

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NfsClientsCache

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NfsClientsCache()
        resource.client_retention_interval = "P7D"
        resource.patch()

## Classes

`class NfsClientsCache (*args, **kwargs)`

  Allows interaction with NfsClientsCache objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves the NFS connected-client cache settings of the cluster.

    ### Learn more

    - `DOC /protocols/nfs/connected-client-settings`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates the properties of the NFS connected-client cache settings.

    ### Learn more

    - `DOC /protocols/nfs/connected-client-settings`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class NfsClientsCacheSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NfsClientsCache object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `client_retention_interval: str GET POST PATCH`

    The lifetime range of the connected-clients cache. Only intervals in multiples of 12 hours or its equivalent in days, minutes or seconds are supported. The minimum is 12 hours and the maximum is 168 hours or 7 days.

  `enable_nfs_clients_deletion: bool GET POST PATCH`

    Specifies whether or not NFS Clients deletion is enabled for the connected-clients cache. When set to "true", connected-clients entries are deleted when a connection is closed.

  `links: SelfLink GET`

    The links field of the nfs_clients_cache.

  `update_interval: str GET`

    The time interval between refreshing the connected-clients cache. The minimum is 1 hour and the maximum is 8 hours.